/*******************************************************************************
 * Copyright (c) 2000, 2005 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 * Port to the D programming language:
 *     Frank Benoit <benoit@tionex.de>
 *******************************************************************************/
module dwtx.jface.text.IInformationControlCreatorExtension;

import dwt.dwthelper.utils;

/**
 * Extension interface for {@link dwtx.jface.text.IInformationControlCreator}<p>
 * Introduces tests whether information controls can be reused and whether information
 * control creators can replace each other.
 *
 * @see dwtx.jface.text.IInformationControlCreator
 * @see dwtx.jface.text.IInformationControl
 * @since 3.0
 */
public interface IInformationControlCreatorExtension {

    /**
     * Tests if an existing information control can be reused.
     *
     * @param control the information control to test
     * @return <code>true</code> if the control can be reused
     */
    bool canReuse(IInformationControl control);

    /**
     * Tests whether this information control creator can replace the given
     * information control creator. This is the case if the two creators create
     * the same kind of information controls.
     *
     * @param creator the creator to be checked
     * @return <code>true</code> if the given creator can be replaced,
     *         <code>false</code> otherwise
     */
    bool canReplace(IInformationControlCreator creator);
}
