/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 * Port to the D programming language:
 *     Frank Benoit <benoit@tionex.de>
 *******************************************************************************/
module dwtx.jface.text.IRepairableDocumentExtension;

import dwt.dwthelper.utils;


/**
 * Extension interface for {@link dwtx.jface.text.IRepairableDocument}.
 * <p>
 * Adds the ability to query whether the repairable document needs to be
 * repaired.
 * 
 * @see dwtx.jface.text.IRepairableDocument
 * @since 3.4
 */
public interface IRepairableDocumentExtension {

    /**
     * Tells whether the line information of the document implementing this
     * interface needs to be repaired.
     * 
     * @param offset the document offset
     * @param length the length of the specified range
     * @param text the substitution text to check
     * @return <code>true</code> if the line information must be repaired
     * @throws BadLocationException if the offset is invalid in this document
     * @see IRepairableDocument#repairLineInformation()
     */
    bool isLineInformationRepairNeeded(int offset, int length, String text) throws BadLocationException;
}
